#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef PACKAGE
#undef GETTEXT_PACKAGE
#undef VERSION
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LANGINFO_D_FMT
#undef HAVE_GMP2_INCLUDE_DIR
#undef HAVE_LIBSM
#undef HAVE_PROGRAM_INVOCATION_NAME
#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
#undef HAVE_SHADOW_H
#undef HAVE_GLIBTOP_MACHINE_H
#undef HAVE_LIBGTKHTML
#undef HAVE_LIBGTOP
#undef NEED_LIBGTOP
#undef HAVE_GUILE
#undef HAVE_LINUX_TABLE
#undef HAVE_GNOME_PRINT
#undef HAVE_LINUX_FD_H
#undef PATH_MESSAGES

/* Define if LibGTop has support for multiple processors. */
#undef HAVE_LIBGTOP_SMP

/* Define if you want to build against development gtk */
#undef HAVE_DEVGTK

/* Define if there is no `u_int64_t' and `int64_t'. */
#undef u_int64_t
#undef int64_t

/*=== Curses version detection defines ===*/
/* Found some version of curses that we're going to use */
#undef HAS_CURSES

/* Use SunOS SysV curses? */
#undef USE_SUNOS_CURSES

/* Use old BSD curses - not used right now */
#undef USE_BSD_CURSES

/* Use SystemV curses? */
#undef USE_SYSV_CURSES

/* Use Ncurses? */
#undef USE_NCURSES

/* If you Curses does not have color define this one */
#undef NO_COLOR_CURSES

/* Define if you want to turn on SCO-specific code */
#undef SCO_FLAVOR

/* Set to reflect version of ncurses *
 *   0 = version 1.*
 *   1 = version 1.9.9g
 *   2 = version 4.0/4.1 */
#undef NCURSES_970530

/* LibGTop major, minor and micro version. */
#undef LIBGTOP_MAJOR_VERSION
#undef LIBGTOP_MINOR_VERSION
#undef LIBGTOP_MICRO_VERSION

/* LibGTop version and numerical version code ("1.234.567" -> 1234567). */
#undef LIBGTOP_VERSION
#undef LIBGTOP_VERSION_CODE

/* LibGTop server version, increased each time the protocol changes. */
#undef LIBGTOP_SERVER_VERSION

#undef USE_PAM
#undef BUILD_GSTRIPCHART_APPLET
#undef BUILD_GCOLORSEL_APPLET

#undef GNOME_ICONDIR
